@@ -89,7 +89,7 @@ iface_to_priority (OobsIface *iface)
     return 2;
   else if (OOBS_IS_IFACE_ETHERNET (iface))
     return 4;
-  else if (OOBS_IS_IFACE_MODEM (iface) || OOBS_IS_IFACE_ISDN (iface))
+  else if (OOBS_IS_IFACE_PPP (iface))
     return 3;
   else
     return 1;
@@ -187,10 +187,8 @@ iface_to_type (OobsIface *iface)
     return "ethernet";
   else if (OOBS_IS_IFACE_PLIP (iface))
     return "plip";
-  else if (OOBS_IS_IFACE_MODEM (iface))
-    return "modem";
-  else if (OOBS_IS_IFACE_ISDN (iface))
-    return "isdn";
+  else if (OOBS_IS_IFACE_PPP (iface))
+    return "ppp";
 
   return "unknown";
 }
@@ -250,7 +248,7 @@ get_iface_pixbuf (OobsIface *iface)
     icon = "gnome-dev-ethernet";
   else if (OOBS_IS_IFACE_PLIP (iface))
     icon = "plip";
-  else if (OOBS_IS_IFACE_ISDN (iface))
+  else if (OOBS_IS_IFACE_PPP (iface))
     icon = "gnome-modem";
 
   if (icon)
@@ -285,16 +283,20 @@ get_iface_secondary_text (OobsIface *iface)
     }
   else if (OOBS_IS_IFACE_ETHERNET (iface))
     {
+      const gchar *config_method;
+
       if (OOBS_IS_IFACE_WIRELESS (iface))
 	g_string_append_printf (str, _("<b>Essid:</b> %s "),
 				oobs_iface_wireless_get_essid (OOBS_IFACE_WIRELESS (iface)));
 
-      if (oobs_iface_ethernet_get_configuration_method (OOBS_IFACE_ETHERNET (iface)) != OOBS_METHOD_DHCP)
+      config_method = oobs_iface_ethernet_get_configuration_method (OOBS_IFACE_ETHERNET (iface));
+
+      if (config_method && strcmp (config_method, "static") == 0)
 	g_string_append_printf (str, _("<b>Address:</b> %s <b>Subnet mask:</b> %s"),
 				oobs_iface_ethernet_get_ip_address (OOBS_IFACE_ETHERNET (iface)),
 				oobs_iface_ethernet_get_network_mask (OOBS_IFACE_ETHERNET (iface)));
       else
-	g_string_append_printf (str, _("<b>Address:</b> DHCP"));
+	g_string_append_printf (str, _("<b>Address:</b> %s"), config_method);
     }
   else if (OOBS_IS_IFACE_PLIP (iface))
     {
@@ -302,11 +304,11 @@ get_iface_secondary_text (OobsIface *iface)
 			      oobs_iface_plip_get_address (OOBS_IFACE_PLIP (iface)),
 			      oobs_iface_plip_get_remote_address (OOBS_IFACE_PLIP (iface)));
     }
-  else if (OOBS_IS_IFACE_ISDN (iface))
+  else if (OOBS_IS_IFACE_PPP (iface))
     {
       g_string_append_printf (str, _("<b>Phone number:</b> %s <b>Login:</b> %s"),
-			      oobs_iface_isdn_get_phone_number (OOBS_IFACE_ISDN (iface)),
-			      oobs_iface_isdn_get_login (OOBS_IFACE_ISDN (iface)));
+			      oobs_iface_ppp_get_phone_number (OOBS_IFACE_PPP (iface)),
+			      oobs_iface_ppp_get_login (OOBS_IFACE_PPP (iface)));
     }
 
   text = str->str;
@@ -330,10 +332,8 @@ get_iface_desc (OobsIface *iface, gboolean show_name)
     primary_text = N_("Wired connection");
   else if (OOBS_IS_IFACE_PLIP (iface))
     primary_text = N_("Parallel port connection");
-  else if (OOBS_IS_IFACE_MODEM (iface))
-    primary_text = N_("Modem connection");
-  else if (OOBS_IS_IFACE_ISDN (iface))
-    primary_text = N_("ISDN connection");
+  else if (OOBS_IS_IFACE_PPP (iface))
+    primary_text = N_("Point to point connection");
 
   secondary_text = get_iface_secondary_text (iface);
 
@@ -403,6 +403,36 @@ ifaces_model_set_interface_at_iter (OobsIface *iface, GtkTreeIter *iter, gboolea
   ifaces_model_modify_interface_at_iter (iter);
 }
 
+static void
+iface_state_changed (OobsIface *iface,
+		     gpointer   user_data)
+{
+  GtkTreeModel *model;
+  GtkTreeIter iter;
+  OobsIface *model_iface;
+  gboolean valid, found;
+
+  found = FALSE;
+  model = GST_NETWORK_TOOL (tool)->interfaces_model;
+  valid = gtk_tree_model_get_iter_first (model, &iter);
+
+  while (valid && !found)
+    {
+      gtk_tree_model_get (model, &iter,
+			  COL_OBJECT, &model_iface,
+			  -1);
+
+      if (iface == model_iface)
+	{
+	  ifaces_model_modify_interface_at_iter (&iter);
+	  found = TRUE;
+	}
+
+      g_object_unref (iface);
+      valid = gtk_tree_model_iter_next (model, &iter);
+    }
+}
+
 void
 ifaces_model_add_interface (OobsIface *iface, gboolean show_name)
 {
@@ -413,6 +443,9 @@ ifaces_model_add_interface (OobsIface *iface, gboolean show_name)
 
   gtk_list_store_append (GTK_LIST_STORE (model), &it);
   ifaces_model_set_interface_at_iter (iface, &it, show_name);
+
+  g_signal_connect (iface, "state-changed",
+		    G_CALLBACK (iface_state_changed), tool);
 }
 
 void
