@@ -41,7 +41,7 @@ set_smb_name (const gchar *name)
 
 	entry = gst_dialog_get_widget (tool->main_dialog, "share_smb_name");
 
-	modified = GPOINTER_TO_INT (g_object_get_data (entry, "modified"));
+	modified = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (entry), "modified"));
 
 	if (!modified) {
 		g_signal_handlers_block_by_func (entry, on_share_smb_name_modified, tool->main_dialog);
@@ -51,13 +51,11 @@ set_smb_name (const gchar *name)
 }
 
 void
-share_settings_set_name_from_folder (void)
+share_settings_set_name_from_folder (const gchar *path)
 {
-	GtkWidget *folder_chooser;
-	gchar *path, *name;
+	gchar *name;
 
-	folder_chooser = gst_dialog_get_widget (tool->main_dialog, "share_path");
-	path = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (folder_chooser));
+	g_return_if_fail (path != NULL);
 
 	if (strcmp (path, "/") == 0)
 		name = g_strdup (_("File System"));
@@ -65,7 +63,6 @@ share_settings_set_name_from_folder (void)
 		name = g_path_get_basename (path);
 
 	set_smb_name (name);
-	g_free (path);
 	g_free (name);
 }
 
@@ -292,7 +289,7 @@ share_settings_get_share_nfs ()
 	widget  = gst_dialog_get_widget (tool->main_dialog, "share_path");
 	path    = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (widget));
 
-	share = oobs_share_nfs_new (path);
+	share = OOBS_SHARE_NFS (oobs_share_nfs_new (path));
 	nfs_acl_table_insert_elements (share);
 
 	return OOBS_SHARE (share);
@@ -341,7 +338,7 @@ share_settings_validate (void)
 	if (selected == SHARE_THROUGH_SMB) {
 		widget = gst_dialog_get_widget (tool->main_dialog, "share_smb_name");
 		text = gtk_entry_get_text (GTK_ENTRY (widget));
-		
+
 		return (text && *text);
 	}
 
@@ -425,31 +422,41 @@ delete_share (GtkTreeIter *iter, OobsShare *share, OobsListIter *list_iter)
 	}
 
 	oobs_list_remove (list, list_iter);
-	table_delete_share_at_iter (&iter);
+	table_delete_share_at_iter (iter);
 
 	oobs_object_commit (config);
 }
 
 void
 share_settings_dialog_run (const gchar *path, gboolean standalone)
+{
+	GtkTreeIter   iter;
+
+	/* check whether the path already exists */
+	if (table_get_iter_with_path (path, &iter))
+		share_settings_dialog_run_for_iter (path, &iter, standalone);
+	else
+		share_settings_dialog_run_for_iter (path, NULL, standalone);
+}
+
+void
+share_settings_dialog_run_for_iter (const gchar *path,
+				    GtkTreeIter *iter,
+				    gboolean standalone)
 {
 	GtkWidget    *dialog;
 	gint          response;
 	OobsShare    *new_share, *share;
 	OobsListIter *list_iter;
-	GtkTreeIter   iter;
-	gboolean      path_exists;
 	gchar        *title;
-	GtkWidget    *name_entry;
+	GtkWidget    *name_entry, *file_chooser;
 
 	share  = NULL;
+	list_iter = NULL;
 	dialog = share_settings_prepare_dialog (path, standalone);
 
-	/* check whether the path already exists */
-	path_exists = table_get_iter_with_path (path, &iter);
-
-	if (path_exists) {
-		share = table_get_share_at_iter (&iter, &list_iter);
+	if (iter) {
+		share = table_get_share_at_iter (iter, &list_iter);
 		share_settings_set_share (share);
 
 		title = g_strdup_printf ("Settings for folder '%s'",
@@ -458,29 +465,39 @@ share_settings_dialog_run (const gchar *path, gboolean standalone)
 		g_free (title);
 	} else {
 		name_entry = gst_dialog_get_widget (tool->main_dialog, "share_smb_name");
-		g_object_set_data (name_entry, "modified", GINT_TO_POINTER (FALSE));
+		g_object_set_data (G_OBJECT (name_entry), "modified", GINT_TO_POINTER (FALSE));
 		gtk_window_set_title (GTK_WINDOW (dialog), "Share Folder");
 
-		share_settings_set_name_from_folder ();
+		if (!path) {
+			/* make sure the path gets filled */
+			file_chooser = gst_dialog_get_widget (tool->main_dialog, "share_path");
+			path = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (file_chooser));
+		}
+
+		share_settings_set_name_from_folder (path);
 	}
 
+	gst_dialog_add_edit_dialog (tool->main_dialog, dialog);
+
 	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (tool->main_dialog));
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_hide (dialog);
 
+	gst_dialog_remove_edit_dialog (tool->main_dialog, dialog);
+
 	if (response == GTK_RESPONSE_OK) {
 		new_share = share_settings_get_share ();
 
 		if (new_share) {
 			/* FIXME: check type, and move
 			 * share between lists if necessary */
-			if (path_exists)
-				modify_share (new_share, share, list_iter, &iter);
+			if (iter)
+				modify_share (new_share, share, list_iter, iter);
 			else
 				add_new_share (new_share);
 		} else {
-			if (path_exists)
-				delete_share (&iter, share, list_iter);
+			if (iter)
+				delete_share (iter, share, list_iter);
 		}
 	}
 
@@ -488,4 +505,7 @@ share_settings_dialog_run (const gchar *path, gboolean standalone)
 
 	if (share)
 		g_object_unref (share);
+
+	if (list_iter)
+		oobs_list_iter_free (list_iter);
 }
