@@ -20,6 +20,7 @@
 
 #include <glib-object.h>
 #include "shares-tool.h"
+#include "users-table.h"
 #include <glib/gi18n.h>
 #include "gst.h"
 
@@ -27,6 +28,10 @@ static void gst_shares_tool_class_init (GstSharesToolClass *class);
 static void gst_shares_tool_init       (GstSharesTool      *tool);
 static void gst_shares_tool_finalize   (GObject            *object);
 
+static GObject * gst_shares_tool_constructor (GType                  type,
+					      guint                  n_construct_properties,
+					      GObjectConstructParam *construct_params);
+
 static void gst_shares_tool_update_gui    (GstTool         *tool);
 static void gst_shares_tool_update_config (GstTool         *tool);
 
@@ -40,6 +45,7 @@ gst_shares_tool_class_init (GstSharesToolClass *class)
 	GObjectClass *object_class = G_OBJECT_CLASS (class);
 	GstToolClass *tool_class = GST_TOOL_CLASS (class);
 
+	object_class->constructor = gst_shares_tool_constructor;
 	object_class->finalize = gst_shares_tool_finalize;
 	tool_class->update_gui = gst_shares_tool_update_gui;
 	tool_class->update_config = gst_shares_tool_update_config;
@@ -50,14 +56,38 @@ gst_shares_tool_init (GstSharesTool *tool)
 {
 	GstTool *gst_tool = GST_TOOL (tool);
 
-	tool->nfs_config = oobs_nfs_config_get (gst_tool->session);
-	tool->smb_config = oobs_smb_config_get (gst_tool->session);
+	tool->nfs_config = oobs_nfs_config_get ();
+	gst_tool_add_configuration_object (gst_tool, tool->nfs_config);
 
-	tool->services_config = oobs_services_config_get (gst_tool->session);
-	tool->hosts_config = oobs_hosts_config_get (gst_tool->session);
-	tool->ifaces_config = oobs_ifaces_config_get (gst_tool->session);
+	tool->smb_config = oobs_smb_config_get ();
+	gst_tool_add_configuration_object (gst_tool, tool->smb_config);
 
-	gst_shares_tool_update_services_availability (tool);
+	tool->services_config = oobs_services_config_get ();
+	gst_tool_add_configuration_object (gst_tool, tool->services_config);
+
+	tool->hosts_config = oobs_hosts_config_get ();
+	gst_tool_add_configuration_object (gst_tool, tool->hosts_config);
+
+	tool->ifaces_config = oobs_ifaces_config_get ();
+	gst_tool_add_configuration_object (gst_tool, tool->ifaces_config);
+
+	tool->users_config = oobs_users_config_get ();
+	gst_tool_add_configuration_object (gst_tool, tool->users_config);
+}
+
+static GObject *
+gst_shares_tool_constructor (GType                  type,
+			     guint                  n_construct_properties,
+			     GObjectConstructParam *construct_params)
+{
+	GObject *object;
+
+	object = (* G_OBJECT_CLASS (gst_shares_tool_parent_class)->constructor) (type,
+										 n_construct_properties,
+										 construct_params);
+	users_table_create (GST_TOOL (object));
+
+	return object;
 }
 
 static void
@@ -157,6 +187,8 @@ gst_shares_tool_update_gui (GstTool *tool)
 		/* disable the tool UI, there's no way to add shares */
 		gtk_widget_set_sensitive (dialog_notebook, FALSE);
 	}
+
+	users_table_set_config (shares_tool);
 }
 
 static void
@@ -165,11 +197,6 @@ gst_shares_tool_update_config (GstTool *tool)
 	GstSharesTool *shares_tool;
 
 	shares_tool = GST_SHARES_TOOL (tool);
-	oobs_object_update (shares_tool->nfs_config);
-	oobs_object_update (shares_tool->smb_config);
-	oobs_object_update (shares_tool->services_config);
-	oobs_object_update (shares_tool->hosts_config);
-	oobs_object_update (shares_tool->ifaces_config);
 	gst_shares_tool_update_services_availability (shares_tool);
 }
 
